#
# To run VASP this script calls $vasp_std
# (or posibly $vasp_gam and/or $vasp_ncl).
# These variables can be defined by sourcing vaspcmd
. vaspcmd 2> /dev/null
#
# When vaspcmd is not available and $vasp_std,
# $vasp_gam, and/or $vasp_ncl are not set as environment
# variables, you can specify them here
[ -z "`echo $vasp_std`" ] && vasp_std="mpirun -np 4 vasp"
[ -z "`echo $vasp_gam`" ] && vasp_gam="mpirun -np 4 vasp_g"
[ -z "`echo $vasp_ncl`" ] && vasp_ncl="mpirun -np 4 vasp_ncl"
#
# The real work starts here
#

echo "
#
# PBE ground state energy 
#
"
cp KPOINTS.BULK KPOINTS
rm WAVECAR
cp INCAR.DFT INCAR
$vasp_std

echo "
#
# increase number of bands
#
"
cp INCAR.PBE INCAR
$vasp_std
cp OUTCAR OUTCAR.PBE
cp WAVECAR WAVECAR.PBE
cp WAVEDER WAVEDER.PBE
cp CHGCAR CHGCAR.PBE

echo "
#
# perform GW calculation based on PBE solution
#
"
cp INCAR.GW0 INCAR
$vasp_std
cp OUTCAR OUTCAR.GW0
cp WAVECAR WAVECAR.GW0 # store GW WAVECAR 

echo "
#
# calculate HSE ground state starting from PBE result
#
"
cp WAVECAR.PBE WAVECAR
cp WAVEDER.PBE WAVEDER
cp INCAR.HSE INCAR
$vasp_std
cp OUTCAR OUTCAR.HSE
cp WAVECAR WAVECAR.HSE

echo "
#------------------------------------------------------------------------
# post processing 
#------------------------------------------------------------------------
#
# interpolate PBE band structure with vasp
#
"
cp INCAR.BSTR INCAR
cp KPOINTS.BSTR KPOINTS  
cp WAVECAR.PBE WAVECAR
cp CHGCAR.PBE CHGCAR
$vasp_std
cp OUTCAR OUTCAR.BSTR
cp EIGENVAL EIGENVAL.BSTR
cp vasprun.xml vasprun.BSTR.xml
cp vaspout.h5 vasprun.BSTR.h5
cp KPOINTS.BULK KPOINTS

for  i in "PBE" "GW0" "HSE" ; do 
   echo "
   #
   # calculate decent DOS of $i calculation
   #
   "
   cp INCAR.DOS INCAR
   cp WAVECAR.$i WAVECAR
    
   $vasp_std
   cp vasprun.xml vasprun.$i.xml
   cp vaspout.h5 vasprun.$i.h5
   cp DOSCAR DOSCAR.$i
   echo "
   #
   # interpolate $i band structure with wannier90
   #
   "
   cp INCAR.WAN.$i INCAR
   cp WAVECAR.$i WAVECAR
   $vasp_std
   cp wannier90_band.dat wannier90_band.$i.dat
done
