#!/bin/bash
#M. Kaltak 10.11.2011

# Files needed: EIGENVAL.BSTR, wannier90.wout"

echo "extracting bands"
if [ ! -f $1 ] ; then
   echo " file $1 not present "
fi

if [ -f kpts.dat ] ;then
rm kpts.dat
fi

nbands=32
band_min=16
band_max=30

nbands=$[$band_max-$band_min+1]
#number of k-points
nkpts=60

#grep reciprocal vectors from wannier90.wout
for j in 1 2 3 ; do
b1[$j]=`grep " b_1 " wannier90.wout | tail -1| awk '{print $2,$3,$4}' |cut -d" " -f$j`
b2[$j]=`grep " b_2 " wannier90.wout | tail -1| awk '{print $2,$3,$4}' |cut -d" " -f$j`
b3[$j]=`grep " b_3 " wannier90.wout | tail -1| awk '{print $2,$3,$4}' |cut -d" " -f$j`
done

#=====================================================================================
#grep energies from EIGENVAL obtained from a previous band structure caluclation
#=====================================================================================

#grep reciprocal vectors from wannier90.wout
for j in 1 2 3 ; do
b1[$j]=`grep " b_1 " wannier90.wout | tail -1 | awk '{print $2,$3,$4}' |cut -d" " -f$j`
b2[$j]=`grep " b_2 " wannier90.wout | tail -1 | awk '{print $2,$3,$4}' |cut -d" " -f$j`
b3[$j]=`grep " b_3 " wannier90.wout | tail -1 | awk '{print $2,$3,$4}' |cut -d" " -f$j`
done

#--------------------------------------
cat $1 | grep "plane waves:" > KPOINT_NUMBERS
kpoints_total=`wc -l KPOINT_NUMBERS | awk '{print $1}'`
length=0

i=0
searchstring_=`awk 'BEGIN{FS=" : "; RS=" plane" }{print $2}' KPOINT_NUMBERS  | head -$[$i+1] | tail -1`
x=`echo "$searchstring_" | cut -c1-8`
y=`echo "$searchstring_" | cut -c9-15`
z=`echo "$searchstring_" | cut -c16-22`
kp=1

#---------------------------------------------------------------------
while [ $i -lt $kpoints_total ]; do
   i=$[$i+$kp]
   #grep reciprocal coordinate of current kpoint from KPOINT_NUMBERS
   searchstring_=`awk 'BEGIN{FS=" : "; RS=" plane" }{print $2}' KPOINT_NUMBERS | head -$i |tail -1`
   x_=`echo "$searchstring_" | cut -c1-8`
   y_=`echo "$searchstring_" | cut -c9-15`
   z_=`echo "$searchstring_" | cut -c16-22`
   dx=`echo "scale=8;$x-($x_)" | bc -l` 
   dy=`echo "scale=8;$y-($y_)" | bc -l` 
   dz=`echo "scale=8;$z-($z_)" | bc -l` 
   #calculate distance between kpoints
   for j in 1 2 3; do
   DX[$j]=`echo "scale=10;$dx*${b1[$j]}+$dy*${b2[$j]}+$dz*${b3[$j]}" | bc -l`
   done
   norm=`echo "scale=10;sqrt(${DX[1]}^2+${DX[2]}^2+${DX[3]}^2)" | bc -l`
   length=`echo "scale=10;$length+$norm" |bc -l`

   #grep energies
   l=0
   for (( k=$band_min; k<=$band_max; k++ )); do
      l=$[$l+1]
      e=`cat EIGENVAL.BSTR | grep  "  $k   " | head -$i | tail -1 | awk '{print $2}'`
      echo " $length $e " >> kpts.dat  
   done
   x=$x_
   y=$y_
   z=$z_
done
#=====================================================================================

if [ -f KPOINT_NUMBERS ] ;then
rm KPOINT_NUMBERS 
fi

if [ -f band_1.dat ] ; then
  rm band_*.dat
fi 

for file in kpts.dat ; do 

for k_ in `seq 1 $nkpts ` ; do 
   
   k=$[${k_}-1]
   
   for b in `seq 1 $nbands` ; do 
       # lines
       lines=$[$k*$nbands+$b]
       head -${lines} $file | tail -1 | awk '{printf "%12.6f %12.6f\n", $1,$2}'>> band_$b.dat
   done
done
done

if [ -f bndstr.pbe ] ; then 
   rm bndstr.pbe 
fi 

for b in `seq 1 $nbands` ; do 
   echo "# band $b " >> bndstr.pbe
   cat band_$b.dat >> bndstr.pbe
   echo " " >> bndstr.pbe

done

rm band_*.dat 
rm kpts.dat 
